/* @flow */
'use strict';

var spawn = require('child_process').spawn;
var _ = require('highland');
var sanitize = require('sanitize-filename');
var Shapefile = require('./shapefile');
var Cmd = require('./ogr-cmd');

function createStream(format, options) {
  options.input = options.input || options.path + '/layer.vrt';
  var output = _();
  options.name = options.name ? sanitize(options.name) : 'output';
  var ogrStream = format === 'zip' ? createShp(options) : spawnOgr(format, options);
  ogrStream.on('log', function (l) {
    return output.emit('log', l);
  }).on('error', function (e) {
    return output.emit('error', e);
  }).pipe(output);

  return output;
}

function spawnOgr(format, options) {
  var output = _();
  var cmd = Cmd.create(format, options);
  output.emit('log', { level: 'info', message: 'Executing: OGR2OGR ' + cmd.join(' ') });
  var ogr = spawn('ogr2ogr', cmd).on('close', function (c) {
    if (c > 0) output.emit('error', new Error('OGR Failed'));
  });

  ogr.stderr.on('data', listen);

  function listen(data) {
    var msg = data.toString();
    // Error 1: GeoJSON parsing error
    // Error 4: Failed to read GeeoJSON
    // Error 6: debug message that can be ignored
    if (msg.match(/ERROR\s[^6]/)) {
      output.emit('error', new Error(msg));
      ogr.stderr.removeListener('data', listen);
      process.kill(ogr.pid, 'SIGKILL');
      output.destroy();
    }
  }

  return ogr.stdout.pipe(output);
}

function createShp(options) {
  var output = _();
  return Shapefile.createStream(options).on('error', function (e) {
    return output.emit('error', e);
  }).on('log', function (l) {
    return output.emit('log', l);
  }).pipe(output);
}

module.exports = { createStream: createStream };